imitation.scripts package
=========================

Submodules
----------

imitation.scripts.analyze module
--------------------------------

.. automodule:: imitation.scripts.analyze

imitation.scripts.eval\_policy module
-------------------------------------

.. automodule:: imitation.scripts.eval_policy

imitation.scripts.parallel module
-------------------------------------------

.. automodule:: imitation.scripts.parallel

imitation.scripts.train\_adversarial module
-------------------------------------------

.. automodule:: imitation.scripts.train_adversarial

imitation.scripts.train\_imitation module
------------------------------------------

.. automodule:: imitation.scripts.train_imitation

imitation.scripts.train\_preference_comparisons module
------------------------------------------------------

.. automodule:: imitation.scripts.train_preference_comparisons

imitation.scripts.train\_rl module
----------------------------------

.. automodule:: imitation.scripts.train_rl

Module contents
---------------

.. automodule:: imitation.scripts
